@@ -815,11 +815,18 @@ def configure_model(args):
     entry = utils.load_description(model)
 
     private = None
+
     if "private" in entry["meta"]:
-        private = entry["meta"]["private"]
-        require_info = [x.strip() for x in private.split(',')]
+        require_info = entry["meta"]["private"]
+
+        private_out = []
+
+        for item in require_info.items():
+            elements = [x.strip() for x in item[1].split(',')]
+            private_out.append([item[0], elements])
+
         private_json_path = os.path.join(pkg_dir, "private.json")
-        generalkey(private_json_path, require_info[0], require_info[1:],
+        generalkey(private_json_path, private_out,
                    verbose=True, ask=not YES)
 
     depspec = None
@@ -1119,9 +1126,8 @@ or else connect to the server's desktop using a local X server like X2Go.
 def donate(args):
     """Consider a donation to the author."""
 
-    print(
-        "Please assist by implementing this command: support donations to the author."
-    )
+    print("Please assist by implementing this command:",
+          "support donations to the author.")
 
 
 # ------------------------------------------------------------------------
@@ -1159,6 +1165,10 @@ def remove_model(args):
         path = utils.get_init_dir()
         if os.path.exists(path):
             msg = "*Completely* remove all installed models in '{}'"
+            if YES:
+                print("MLHub does not allow automatic uninstall",
+                      "without questioning it!\n")
+            YES = False
         else:
             msg = "The local model folder '{}' does not exist. Nothing to do."
             msg = msg.format(path)
@@ -1193,7 +1203,7 @@ def remove_model(args):
 
     else:
 
-        if utils.yes_or_no(msg, path, yes=True):
+        if utils.yes_or_no(msg, path, yes=False, certain=True):
 
             # Remove package installation dir
 
@@ -1216,4 +1226,5 @@ def remove_model(args):
                     shutil.rmtree(archive)
         else:
             if model is None and not args.quiet:
-                utils.print_next_step("remove")
+                print("\nMLHub has not been removed.")
+                utils.print_next_step("uninstall")
